Qubit Thread Pool
Dynamic and fixed-size thread pool executor services.
Modules
- service
- Executor service compatibility exports for thread-pool users.
Structs
- Fixed
Thread Pool - Fixed-size thread pool implementing
ExecutorService. - Fixed
Thread Pool Builder - Builder for
FixedThreadPool. - PoolJob
- Type-erased pool job with a cancellation path for queued work.
- Shutdown
Report - Summary returned by an immediate executor-service shutdown request.
- Task
Handle - Handle for a task running outside the caller’s current stack.
- Thread
Pool - OS thread pool implementing
ExecutorService. - Thread
Pool Builder - Builder for
ThreadPool. - Thread
Pool Stats
Enums
- Rejected
Execution - Error returned when an executor service refuses to accept a task.
- Task
Execution Error - Error observed when retrieving the result of an accepted task.
- Thread
Pool Build Error - Error returned when a
super::thread_pool::ThreadPoolcannot be built.
Traits
- Executor
Service - Managed task service with submission and lifecycle control.
Type Aliases
- Task
Result - Result type used by managed task handles.