Crate qubit_thread_pool

Crate qubit_thread_pool 

Qubit Thread Pool

Dynamic and fixed-size thread pool executor services.

Author

Haixing Hu

Modules

service
Executor service compatibility exports for thread-pool users.

Structs

FixedThreadPool
Fixed-size thread pool implementing ExecutorService.
FixedThreadPoolBuilder
Builder for FixedThreadPool.
PoolJob
Type-erased pool job with a cancellation path for queued work.
ShutdownReport
Summary returned by an immediate executor-service shutdown request.
TaskHandle
Handle for a task running outside the caller’s current stack.
ThreadPool
OS thread pool implementing ExecutorService.
ThreadPoolBuilder
Builder for ThreadPool.
ThreadPoolStats

Enums

RejectedExecution
Error returned when an executor service refuses to accept a task.
TaskExecutionError
Error observed when retrieving the result of an accepted task.
ThreadPoolBuildError
Error returned when a super::thread_pool::ThreadPool cannot be built.

Traits

ExecutorService
Managed task service with submission and lifecycle control.

Type Aliases

TaskResult
Result type used by managed task handles.